#ifndef ACCOUNT_H
#define ACCOUNT_H


#include <regex.h>

#include "config.h"


/* String lengths of account settings. */
#define SERVER_LEN			(635 + 1)	/* Section 2.5 RFC 1123. */
#define USERNAME_LEN			128
#define PASSWORD_LEN			128

/* Attributes of a password. */
#define PASSWORD_NONE			0
#define PASSWORD_PLAIN			1
#define PASSWORD_ENCRYPTED		2

/* Secure Socket Layer protocols. */
#define SSL_DISABLED			0
#define SSL_SSL_V2			1
#define SSL_SSL_V3			2
#define SSL_TLS_V1			3

/* String length of keys (aliases). */
#define KEY_LEN				32

/* String length of mailbox's name. */
#define MBOX_NAME_LEN			128

/* Maximum filters assigned to a mailbox. */
#define MBOX_FILTERS_MAX		64

/* Maximum mailboxes contained in a mailbox-group. */
#define MBOXGRP_MBOXES_MAX		64


/* Account. */
typedef struct account {
	char key[KEY_LEN];	/* Alias of account. */
	char server[SERVER_LEN];/* Hostname of mail server. */
	unsigned short int port;/* Port to connect. */
	char username[USERNAME_LEN];	/* Username. */
	char *password;		/* Password. */
	int passwdattr;		/* Password attributes. */
	unsigned int ssl;	/* Secure Socket Layer support. */
	struct mbox *mboxes;	/* Mailboxes. */
	struct account *next;	/* Next node of linked list. */
} account_t;

/* Mailbox. */
typedef struct mbox {
	char name[MBOX_NAME_LEN];	/* Name of mailbox. */
	struct filter *filters[MBOX_FILTERS_MAX];	/* Filters to be
							 * applied. */
	struct mbox *next;	/* Next node of linked list. */
} mbox_t;

/* Group of mailboxes. */
typedef struct mboxgrp {
	char key[KEY_LEN];	/* Alias of mailbox group. */
	struct mbox *mboxes[MBOXGRP_MBOXES_MAX];	/* Mailboxes of group. */
	struct mboxgrp *left, *right;	/* Left/right nodes of tree. */
} mboxgrp_t;


/*	account.c	*/
int set_account(char *line, regmatch_t * match);
int set_mboxgrp(char *line, regmatch_t * match);

#ifdef ENCRYPTED_PASSWORDS
char *find_password(char *user, char *serv);
#endif

char *apply_namespace(char *mbox, char *prefix, char delim);


#endif				/* ACCOUNT_H */
